@@ -140,9 +140,12 @@ class Config(object):
 
 
 @contextmanager
-def temppath():
+def temppath(dir=None):
   """Create a temporary path.
 
+  :param dir: Explicit directory name where to create the temporary path. A
+    system dependent default will be used otherwise (cf. `tempfile.mkstemp`).
+
   Usage::
 
     with temppath() as path:
@@ -152,7 +155,7 @@ def temppath():
   afterwards.
 
   """
-  (desc, path) = mkstemp()
+  (desc, path) = mkstemp(dir=dir)
   close(desc)
   remove(path)
   try:
